#
# spec file for package i3-gaps
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           i3-gaps
Version:        4.18
Release:        lp152.1.5
Summary:        Tiling window manager
License:        BSD-3-Clause
Group:          System/GUI/Other
URL:            https://github.com/Airblader/i3
Source0:        https://github.com/Airblader/i3/releases/download/%{version}/i3-%{version}.tar.bz2#/%{name}-%{version}.tar.bz2
BuildRequires:  asciidoc
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gcc
BuildRequires:  libyajl-devel
BuildRequires:  make
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  xmlto
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(libev)
BuildRequires:  pkgconfig(libpcre)
BuildRequires:  pkgconfig(libstartup-notification-1.0)
BuildRequires:  pkgconfig(pangocairo)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-cursor)
BuildRequires:  pkgconfig(xcb-icccm)
BuildRequires:  pkgconfig(xcb-keysyms)
BuildRequires:  pkgconfig(xcb-xrm)
BuildRequires:  pkgconfig(xkbcommon-x11)
# So that M-enter works in the default config. boo#985443
Recommends:     dmenu
Recommends:     i3lock
# introduced to fix bnc#971897 and boo#985443
Recommends:     i3status
Conflicts:      i3
# Needed to fix bnc#992972
Provides:       i3
Provides:       windowmanager
# Upstream First - Policy:
# Never add any patches to this package without the upstream commit id
# in the patch. Any patches added here without a very good reason to make
# an exception will be silently removed with the next version update.

%description
i3-gaps is a fork of i3, which adds features such as gaps between tiles.

%package devel
Summary:        Development headers for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{name}
# i3 and i3-gaps both provide /usr/include/i3/ipc.h and the same docs
Conflicts:      i3-devel

%description devel
Development headers for the %{name} window manager

%prep
%setup -q -n i3-%{version}

# fix rpmlint E: env-script-interpreter
sed -i 's,^#!/usr/bin/env ,#!/usr/bin/,' i3-dmenu-desktop i3-migrate-config-to-v4 i3-save-tree

%build
# Fix Leap 42.x build
%if 0%{?suse_version} == 1315 && 0%{?is_opensuse}
export YAJL_LIBS="-lyajl" YAJL_CFLAGS="-I/usr/include/yajl"
%endif
%configure
sed -i 's/(TEST_LOGS:/(TEST_LOGS):/' Makefile
%make_build -C *-suse-linux-gnu*

%install
%make_install
%suse_update_desktop_file %{buildroot}%{_datadir}/applications/i3.desktop

%files
%license LICENSE
%doc RELEASE-NOTES-*
%{_mandir}/man1/i3*.1%{?ext_man}
%{_bindir}/i3
%{_bindir}/i3-dump-log
%{_bindir}/i3-with-shmlog
%{_bindir}/i3bar
%{_bindir}/i3-config-wizard
%{_bindir}/i3-dmenu-desktop
%{_bindir}/i3-input
%{_bindir}/i3-migrate-config-to-v4
%{_bindir}/i3-msg
%{_bindir}/i3-nagbar
%{_bindir}/i3-save-tree
%{_bindir}/i3-sensible-editor
%{_bindir}/i3-sensible-pager
%{_bindir}/i3-sensible-terminal
%dir %{_sysconfdir}/i3/
%config %{_sysconfdir}/i3/config
%config %{_sysconfdir}/i3/config.keycodes
%{_datadir}/xsessions/i3.desktop
%{_datadir}/xsessions/i3-with-shmlog.desktop
%{_datadir}/applications/i3.desktop

%files devel
%dir %{_includedir}/i3/
%dir %{_datadir}/doc/i3
%doc %{_datadir}/doc/i3/*.html
%{_includedir}/i3/ipc.h

%changelog
* Mon Mar  9 2020 Avindra Goolcharan <avindra@opensuse.org>
- Update to version 4.18:
  * Changes
    + layout saving: remanage window after property updates (e.g.
    titles)
    + get_first_output: prefer primary output (e.g. when moving
    disabled outputs)
    + ipc: add window_type to nodes
    + ipc: add container id to nodes
    + allow dragging active titles for all container types (e.g.
    floating+tabbed)
    + allow dragging inactive titles after a 10px threshold
    + make tray icon order deterministic (sorted by class/instance)
    + implement focus next|prev
    + implement focus next|prev sibling
    + implement focus_wrapping workspace
    + exit with exit code 0 on --help
    + exec command: respect command criteria
  * Bugfixes
    + build: fix lcov support
    + build: use AC_REPLACE_FUNCS, drop bundled memmem
    + build: fix building with -fno-common (for gcc 10)
    + build: configure: deal with git worktree checkouts, where
    .git is a file
    + i3-nagbar: make debug log visible
    + i3-nagbar: fix small memory leaks
    + i3bar: fix small memory leaks
    + move workspace to output: don’t create duplicate numbered
    workspace
    + correctly select output when pointer query fails
    + fix moving windows to scratchpad when using marks
    + fix startup workspace selection when workspace command
    uses options
    + do not try to center floating window on itself (fixes
    xterm placement)
    + fix “move window to <mark>” when target is a workspace
    + correctly activate windows behind a fullscreen window
    + fix back-and-forth after renaming workspaces
    + keep focus when moving container to marked workspace
    + do not show scratchpad windows upon move to position
    command
    + reparent windows to their current position when unmanaging
    (fixes dock clients unexpectedly moving to different output)
    + fix crash when moving containers
    + scratchpad_move: un-fullscreen correct container
    + avoid crash when nc->window is NULL
* Sat Sep 14 2019 Avindra Goolcharan <avindra@opensuse.org>
- Update to version 4.17.1:
  * Bugfixes
    + unset _I3_RESTART_FD after restart (fixes crashes on restart)
    + default config: immediately refresh i3status after volume changes
    + default config: add XF86AudioMicMute
    + default config: mention loginctl lock-session alongside xss-lock
    + default config: use workspace number, not just workspace
* Tue Aug  6 2019 antoine.belvire@opensuse.org
- Update to version 4.17:
  * Changes:
    + config: make binding modes case-sensitive
    + default config: mention ~/.config/i3/config
    + default config: start xss-lock, nm-applet, pactl (volume
    keys)
    + docs/userguide: update syntax in strip_workspace_*
    + docs/userguide: add a section about hidpi displays
    + docs/userguide: document mark --replace
    + docs/userguide: uncomment and update mark section example
    + docs/userguide: point out differences of normal/pixel title
    bars
    + docs/userguide: clarify which config directives can be used
    at runtime
    + docs/userguide: for_window is a directive, not a command
    + docs/ipc: clarify event/reply types
    + docs/ipc: mention new i3-ipc++ C++ library
    + docs/ipc: clarify restart/exit behavior
    + docs/i3bar-protocol: add markup
    + man/i3.man: fix config file search order
    + ipc: make restart command send a reply once restart
    completed
    + ipc: use queue for all messages; fixes i3bar issues when
    switching between workspaces with many windows
    + i3-dump-log: clarify log message
    + i3-msg: exit with status code 2 when i3 returns an error
    + render left and right borders of titles in stacked mode
    + make swap work with floating windows, fix swap crash
    + switch to clang-format-6.0
    + add input and bounding shapes support (e.g. for the
    https://github.com/phw/peek screen recorder)
    + preserve back_and_forth across restarts
    + allow partial UTF-8 to UCS-2 conversion for better handling
    of title bar content which cannot be represented (e.g. emoji)
    when using bitmap pixel fonts
    + check for duplicate key bindings in i3 -C
    + i3bar: support transparency via --transparency flag (RGBA)
    + i3bar: support for user-defined border widths
  * Bugfixes:
    + build: correctly depend on glib (for g_utf8_make_valid)
    + build: fix build when git is configured to show signatures
    + ipc: report correct workspace in init event after workspace
    move
    + ipc: send missing window:focus event
    + i3bar: correctly recognize click events with text alignment
    + i3bar: fix running without fd 0
    + i3bar: correctly handle button presses on separator
    + i3 --moreversion: warn when $DISPLAY is unset
    + i3bar: support disabling click events
    + release.sh: persist correct version number in docs
    + accept output names containing spaces (e.g. in assignment)
    + fix cursor resizing positioning
    + fix aspect ratio issues (e.g. with mpv)
    + fix brief focus flicker when renaming workspaces
    + fix crash when canceling i3 via ctrl+c
    + fix heap-use-after-free, memory leak
    + fix focus bugs in enabling/disabling RandR outputs
    + fix crash with popups when fullscreen is non-leaf
    + fix crash when moving a second window to mark
    + fix crash with programs with splash screen
    + fix atoms when closing inactive workspace
    + apply title_align to non-leaf containers
    + layout loading: correctly mark non-leaf containers
    + truncate wm_name utf8 strings to first zero byte
    (makes window titles work with buggy clients)
    + fix crash in workspace moving
    + export I3SOCK environment variable (again)
    + fix hanging flaky testcase by using the correct X11
    connection
    + resize: add missing error replies
    + don't pop up floating windows on the wrong workspace
    + remove extra \n from errx and die calls
* Wed Apr 10 2019 Avindra Goolcharan <avindra@opensuse.org>
- update to 4.16.1
  * Truncate wm_name utf8 strings to first zero byte (fixes window
    title corruption)
  * Apply title_align to non-leaf containers. Also, marks will now
    display for non-leaf containers.
  * attach_to_workspace: set new parent before tree_render (fixes
    a heap-use-after-free)
  * Use ipc queue for all messages (fixes an i3bar crash)
  * Fix crash with popups when fullscreen is non-leaf
  * Fix: render_con shows floating containers on wrong workspace
* Mon Nov  5 2018 sean@suspend.net
- update to 4.16
  * see https://github.com/Airblader/i3/blob/4.16/RELEASE-NOTES-4.16
    for bugs fixed, features added, etc
  * drop i3-asciidoc-fix.patch (ascii for title bar has been fixed) (bsc#1075764)
- switch to release tarball (drop auto* deps)
* Thu Apr 12 2018 tiwai@suse.de
- Fix build with asciidoctor (bsc#1075764):
  i3-asciidoc-fix.patch
* Thu Mar 15 2018 avindra@opensuse.org
- update to 4.15.0.1
  * minor: fix version so it's recognized as a release version.
* Sun Mar 11 2018 avindra@opensuse.org
- update to 4.15
  * i3-sensible-terminal: add “kitty”, “guake”, “tilda”
  * i3-sensible-editor: add “gvim”
  * dump-asy: add prerequisite checks
  * dump-asy: fix warnings about empty container names
  * i3-dump-log: enable shmlog on demand
  * i3bar: add --release flag for bindsym in bar blocks
  * i3bar: add relative coordinates in JSON for click events
  * ipc: rename COMMAND to RUN_COMMAND for consistency
  * ipc: implement tick event for less flaky tests
  * ipc: add error reply to “focus <window_mode>”
  * ipc: send success response for nop
  * introduce “assign <criteria> [→] [workspace] [number] <workspace>”
  * introduce “assign <criteria> [→] output left|right|up|down|primary|<output>”
  * introduce a “focus_wrapping” option (subsumes “force_focus_wrapping”)
  * introduce percentage point resizing for floating containers:
    “resize set <width> [px | ppt] <height> [px | ppt]”
  * introduce “resize set <width> ppt <height> ppt” for tiling windows
  * rename “new_window” and “new_float” to “default_border” and
    “default_floating_border” (the old names keep working)
  * output names (e.g. “DP2”) can now be used as synonyms for
    monitor names (e.g. “Dell UP2414Q”).
  * the “swap” command now works with fullscreen windows
  * raise floating windows to top when they are focused
    programmatically
  * _NET_ACTIVE_WINDOW: invalidate focus to force SetInputFocus call
  * make focus handling consistent when changing focus between outputs
  * round non-integer Xft.dpi values
  * tiling resize: remove minimum size
  * doc updates to ipc and userguide, some changes to default config
  * i3bar: fix various memory leaks
  * i3bar: fix crash when no status_command is provided
  * fix incorrectly set up signal handling
  * fix crash when specifying invalid con_id for “swap”
  * fix crash upon restart with window marks
  * fix crash when config file does not end in a newline
  * fix crash in append_layout
  * fix crash in layout toggle command
  * fix crash when switching monitors
  * fix use-after-free in randr_init error path
  * fix move accidentally moving windows across outputs
  * fix crash when floating window is tiled while being resized
  * fix out-of-bounds memory read
  * fix memory leak when config conversion fails
  * fix layout toggle split, which didn’t work until enabling
    tabbed/stack mode once
  * move XCB event handling into xcb_prepare_cb
  * avert endless loop on unexpected EOF in ipc messages
  * perform proper cleanup for signals with Term action
  * don’t match containers in the scratchpad with criteria
  * fix “workspace show” related issues
  * fix config file conversion with long variable names
  * fix config file conversion memory initialization
  * prevent access of freed workspace in _workspace_show
  * disable fullscreen when required when programmatically
    focusing windows
  * free last_motion_notify
  * don’t raise floating windows when focused because of
    focus_follows_mouse
  * correctly set EWMH atoms when closing a workspace
  * don’t raise floating windows when workspace is shown
  * keep focus order when encapsulating workspaces
  * validate layout files before loading
- cleanup with spec-cleaner
* Fri Oct 27 2017 dimstar@opensuse.org
- Have i3-gaps-devel conflict with i3-devel.
* Sat Oct  7 2017 aavindraa@gmail.com
- Fix Leap 42.x build
- Drop _service file
- Drop dead code in .spec file
- Properly set "Conflict" to other providers of i3
* Sun Sep 24 2017 aavindraa@gmail.com
- bump to 4.14.1
- Create _service file
- Fix 32-bit ARM build
* Mon Sep  4 2017 aavindraa@gmail.com
- Bump to 4.14
- Reformat spec file to match i3
